#!/usr/bin/env python

from distutils.core import setup

setup(name='heare-config',
      version='0.0.6',
      description='Heare.io Configuration Utilities',
      author='Sean Fitzgerald',
      author_email='seanfitz@heare.io',
      url='https://github.com/heare-io/heare-config',
      packages=['heare.config'],
      )
